#ifndef V2VDSRC_H
#define V2VDSRC_H

#include <wireless-phy.h>
#include <packet-stamp.h>
#include <propagation.h>
#include <rng.h>

#define BUFF_SIZE 4096
#define SUBURBAN 0
#define HIGHWAY 1
#define RURAL 2

class VanetProp : public Propagation {
	public:
		VanetProp();
		virtual double Pr(PacketStamp *t, PacketStamp *r, WirelessPhy *ifp);
		double dualSlope(PacketStamp *t, PacketStamp *r, double lambda, double L, double &dist, double &scatter);
		virtual int command(int argc, const char*const* argv);
		//get interference distance
		virtual double getDist(double Pr, double Pt, double Gt, double Gr,
			 double hr, double ht, double L, double lambda);
		~VanetProp();

	private:
		RNG *ranVar;	
		int seed;
		int initialized;

		//pathloss exponents for the large-scale model
		double gamma1_suburban, gamma2_suburban, gamma1_highway, gamma2_highway, gamma1_rural, gamma2_rural;	
		//the standard deviation for the log normal shadowing
		double std_db1_suburban, std_db2_suburban, std_db1_highway, std_db2_highway, std_db1_rural, std_db2_rural;
		//the critical distance for the dual slope model
		double dc_suburban, dc_highway, dc_rural;

		double **envelop_data;		//this array is used to load data from the file
		int a_col;			//number of spectrums
		double **node_time_index;	//those 2 variables are used to store the previous 
		double **node_sched_time;	//time for nodes.
		double fs;			//sampling rate of data in the file
		int N;				//number of samples in file
		double fm0;			//maximum doppler frequency in file
		double fm;			//maximum doppler frequency in scenario
		int max_node_id;
		int environment;		/*	= 0 suburban
						  	= 1 highway
							= 2 rural
						*/
		int d0;				// the reference distance
		BaseTrace *pwr_tracer;
		void trace(double index, double dist, double pl, double fad_prw, double scatter);
		int loadFile(const char *file_name);
		double Interpolate(int, int, int a_ind);
};

#endif
	
